@@ -1,5 +1,7 @@
 import redis
+
 import time
+
 from scrapy.dupefilter import BaseDupeFilter
 from scrapy.utils.request import request_fingerprint
 
@@ -10,10 +12,11 @@ class RFPDupeFilter(BaseDupeFilter):
     def __init__(self, server, key):
         """Initialize duplication filter
 
-        Parameters:
-            server -- Redis connection
-            key -- redis key to store fingerprints
-
+        Parameters
+        ----------
+        server : Redis instance
+        key : str
+            Where to store fingerprints
         """
         self.server = server
         self.key = key
@@ -29,6 +32,10 @@ class RFPDupeFilter(BaseDupeFilter):
         key = "dupefilter:%s" % int(time.time())
         return cls(server, key)
 
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls.from_settings(crawler.settings)
+
     def request_seen(self, request):
         fp = request_fingerprint(request)
         added = self.server.sadd(self.key, fp)
@@ -41,4 +48,3 @@ class RFPDupeFilter(BaseDupeFilter):
     def clear(self):
         """Clears fingerprints data"""
         self.server.delete(self.key)
-
